@@ -2295,7 +2295,8 @@ class WSGIGateway(Gateway):
         # exc_info tuple."
         if self.req.sent_headers:
             try:
-                raise exc_info[0], exc_info[1], exc_info[2]
+                #raise exc_info[0], exc_info[1], exc_info[2]
+                raise exc_info[0]
             finally:
                 exc_info = None
 
