@@ -14,13 +14,15 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 import re
 import sys
 import importlib
 from calculate.lib.utils.tools import drop_slash
-from utils.text import convertStrListDict, _u, _u8, formatListOr
-from utils.files import pathJoin
-from utils.portage import searchProfile, RepositorySubstituting, RepositoryPath
+from .utils.text import convertStrListDict, _u, _u8, formatListOr
+from .utils.files import pathJoin
+from .utils.portage import searchProfile, RepositorySubstituting, RepositoryPath
 from os import path
 import os
 from collections import OrderedDict, Iterable
@@ -30,7 +32,8 @@ import operator
 import traceback
 from string import Formatter
 from contextlib import contextmanager
-from types import StringTypes, GeneratorType
+# from types import StringTypes, GeneratorType
+from types import GeneratorType
 from calculate.lib.configparser import ConfigParser, ParsingError
 
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
@@ -694,13 +697,13 @@ class TableVariable(Variable):
 
     def get(self, hr=HumanReadable.No):
         """Get table data"""
-        for varname, value in ifilter(lambda x: type(x[1]) != list,
-                                      imap(lambda x: (x, self.Get(x)),
+        for varname, value in filter(lambda x: type(x[1]) != list,
+                                      map(lambda x: (x, self.Get(x)),
                                            self.source)):
             raise VariableError(
                 _("Source variable %s does not contain a list") % varname)
         return map(list,
-                   izip_longest(
+                   zip_longest(
                        *map(lambda x: self.Get(x, humanreadable=hr),
                             self.source), fillvalue='')) or [[]]
 
@@ -821,7 +824,7 @@ class TableVariable(Variable):
             oldvalue = newval
             try:
                 self.parent.Set(self.source[0], oldvalue.keys())
-            except VariableError, e:
+            except VariableError as e:
                 error.append(e)
         # update entry by index field
         else:
@@ -831,7 +834,7 @@ class TableVariable(Variable):
                              oldvalValues):
             try:
                 self.parent.Set(col, list(vals))
-            except VariableError, e:
+            except VariableError as e:
                 error.append(e)
         for num, varname in writeCols[len(oldvalValues):]:
             self.parent.Invalidate(varname, True)
@@ -1048,6 +1051,7 @@ class SimpleDataVars(object):
             return getList()(value)
         if "table" in varType:
             return map(getList(':'), value.split(','))
+        value = str(value, "UTF-8")
         return fixEmpty(value).strip("'").strip('"')
 
     def ZipVars(self, *argvVarNames, **kw):
@@ -1131,8 +1135,8 @@ class SimpleDataVars(object):
         if func or _if:
             if _if:
                 func = _if
-            if func.func_code.co_argcount > 1:
-                filterFunc = lambda x: func(*x[:func.func_code.co_argcount])
+            if func.__code__.co_argcount > 1:
+                filterFunc = lambda x: func(*x[:func.__code__.co_argcount])
             else:
                 filterFunc = func
         elif eq is not None:
@@ -1247,7 +1251,7 @@ class DataVars(SimpleDataVars):
             data = self.defaultData
         try:
             varModule = importlib.import_module(data)
-        except (ImportError, AttributeError), e:
+        except (ImportError, AttributeError) as e:
             self.raiseModuleError(data, e)
             return False
         # get all Variable classes from module
@@ -1256,14 +1260,14 @@ class DataVars(SimpleDataVars):
             section = varModule.section
         else:
             section = "main"
-        for varMod in map(lambda x: getattr(varModule, x),
+        for varMod in list(map(lambda x: getattr(varModule, x),
                           filter(lambda x: (not x.startswith("_") and
                                                     "Variable" not in x),
-                                 dir(varModule))) + [varModule]:
-            for classname in ifilterfalse(
+                                 dir(varModule)))) + [varModule]:
+            for classname in filterfalse(
                     ("ReadonlyVariable", "VariableInterface",
                      "Variable", "VariableError").__contains__,
-                    ifilter(lambda x: x.startswith("Variable"),
+                    filter(lambda x: x.startswith("Variable"),
                             dir(varMod))):
                 varObj = getattr(varMod, classname)
                 varName = varObj.getVariableName()
@@ -1388,8 +1392,7 @@ class DataVars(SimpleDataVars):
                              path.join(profiledir, os.readlink(make_profile)))]
             else:
                 profiles = []
-            for iniName, iniFile in profiles + \
-                    self.Get('main.cl_env_data'):
+            for iniName, iniFile in profiles + list(self.Get('main.cl_env_data')):
                 if path.exists(iniFile) or iniName == 'profile':
                     config = ConfigParser(strict=False)
                     if iniName == 'profile':
@@ -1543,7 +1546,7 @@ class DataVars(SimpleDataVars):
                     for dep in genReqs(var):
                         yield dep
                 if hasattr(varObj, "source") and varObj.source:
-                    for varsource in imap(self.getInfo, varObj.source):
+                    for varsource in map(self.getInfo, varObj.source):
                         for dep in genReqs(varsource):
                             yield dep
 
@@ -1632,7 +1635,7 @@ class DataVars(SimpleDataVars):
             if not header:
                 header = self.loadVariables[varname].section
             # write value to ini file
-            import cl_ini_parser
+            from . import cl_ini_parser
             config = cl_ini_parser.iniParser(iniFile)
             val = self.serialize(self.getInfo(varname).type,
                                  val)
@@ -1667,7 +1670,7 @@ class DataVars(SimpleDataVars):
                     self.loadVariable(varname)
                 header = self.loadVariables[varname].section
             # write value to ini file
-            import cl_ini_parser
+            from . import cl_ini_parser
             config = cl_ini_parser.iniParser(iniFile)
             allVars = config.getAreaVars(header)
             if allVars is False:
@@ -1814,14 +1817,14 @@ class DataVars(SimpleDataVars):
                                     [self.getInfo(x).type for x in
                                      varObj.source]))
             if multiLists:
-                val = list(izip_longest(*val, fillvalue=""))
+                val = list(zip_longest(*val, fillvalue=""))
                 for col, typecol in multiLists:
                     if col < len(val):
                         val[col] = map(
                             lambda x: x.split(',')
-                            if type(x) in StringTypes else x,
+                            if type(x) in (str) else x,
                             val[col])
-                val = list(izip_longest(*val, fillvalue=""))
+                val = list(zip_longest(*val, fillvalue=""))
         return val
 
     def plainList(self, *elements):
@@ -1839,14 +1842,14 @@ class DataVars(SimpleDataVars):
         """
         Вывести группу переменных
         """
-        print "=DEBUG.SET="
+        print("=DEBUG.SET=")
         for vname in sorted(filter(lambda x: x.lower() == x,
                                    info._type_info.keys())):
-            print "|", vname, "=", getattr(info, vname)
-        print "=DEBUG.DATAVARS="
+            print("|", vname, "=", getattr(info, vname))
+        print("=DEBUG.DATAVARS=")
         for vname in self.mapVarGroup.keys():
-            print "|", vname, "=", self.Get(vname)
-        print "=DEBUG.END="
+            print("|", vname, "=", self.Get(vname))
+        print("=DEBUG.END=")
 
     def checkGroups(self, info, allvars=False, invalidators=None):
         """
@@ -1984,8 +1987,8 @@ class DataVars(SimpleDataVars):
                                        var) if var else "",
                                    'message': mess})
                 except BaseException as e:
-                    for i in apply(traceback.format_exception, sys.exc_info()):
-                        print i,
+                    for i in traceback.format_exception(*sys.exc_info()):
+                        print(i, end=' ')
                     errors.append({'type': 'error', 'field': var,
                                    'message': str(e)})
         return errors
@@ -1993,11 +1996,11 @@ class DataVars(SimpleDataVars):
     def printDependence(self):
         for key, val in self.loadVariables.items():
             if val.reqVars:
-                print key, "->", [x.name for x in val.reqVars]
+                print(key, "->", [x.name for x in val.reqVars])
 
     def printVars(self, filt=lambda x: x):
         for i in sorted(filter(filt, self.allVars.keys())):
-            print "{0:<40} {1}".format(i, self.Get(i, True))
+            print("{0:<40} {1}".format(i, self.Get(i, True)))
 
     def reinit(self):
         """
@@ -2007,7 +2010,7 @@ class DataVars(SimpleDataVars):
             var.init()
 
     def printWrong(self, filt=lambda x: x):
-        print "!!!WRONG VARS!!!"
+        print("!!!WRONG VARS!!!")
         for i in sorted(filter(filt, self.allVars.keys())):
             if self.getInfo(i).untrusted:
-                print "{0:<40} {1}".format(i, self.Get(i, True))
+                print("{0:<40} {1}".format(i, self.Get(i, True)))
