@@ -14,17 +14,19 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import sys
 import os
 import re
 from calculate.lib.utils.tools import SingletonParam
-import files
-import device
+from . import files
+from . import device
 import errno
 from contextlib import contextmanager
-from files import process, makeDirectory
-from tools import traverse
+from .files import process, makeDirectory
+from .tools import traverse
 import tempfile
+from functools import reduce
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -83,7 +85,7 @@ class MountHelper(object):
     NAME, DIR, TYPE, OPTS, FREQ, PASSNO = range(0, 6)
 
     def __init__(self, data_file=None, devs=()):
-        from device import getUUIDDict
+        from .device import getUUIDDict
         if data_file:
             self.data_file = data_file
         self.cache = []
