@@ -14,18 +14,19 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import sys
 from calculate.lib.datavars import ReadonlyVariable
 
-import X11
-import locale
-import env
-import hardware
-import linux
-import net
-import user
-import system
-import action
+from . import X11
+from . import locale
+from . import env
+from . import hardware
+from . import linux
+from . import net
+from . import user
+from . import system
+from . import action
 from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_lib3',sys.modules[__name__])
 
